## Basic Normalizations

??? info "L1, L2, Max Normalizations"
    ::: similaripy.normalize

## TF-IDF and BM25 Families

??? info "TF-IDF"
    ::: similaripy.tfidf

??? info "BM25 Normalization"
    ::: similaripy.bm25

??? info "BM25+ Normalization"
    ::: similaripy.bm25plus